@@ -12,6 +12,7 @@ from fastapi_template.input_model import (
     SUPPORTED_ORMS,
     ORMS_WITHOUT_MIGRATIONS,
     ORM,
+    APIType,
     BuilderContext,
     DB_INFO,
     DatabaseType,
@@ -47,6 +48,14 @@ def parse_args():
         dest="project_description",
         help="Project description",
     )
+    parser.add_argument(
+        "--api-type",
+        help="API type",
+        type=str,
+        choices=list(map(attrgetter("value"), APIType)),
+        default=None,
+        dest="api_type",
+    )
     parser.add_argument(
         "--db",
         help="Database",
@@ -73,11 +82,18 @@ def parse_args():
     )
     parser.add_argument(
         "--redis",
-        help="Add redis support",
+        help="Add Redis support",
         action="store_true",
         default=None,
         dest="enable_redis",
     )
+    parser.add_argument(
+        "--rabbit",
+        help="Add RabbitMQ support",
+        action="store_true",
+        default=None,
+        dest="enable_rmq",
+    )
     parser.add_argument(
         "--migrations",
         help="Add migrations support",
@@ -87,7 +103,7 @@ def parse_args():
     )
     parser.add_argument(
         "--kube",
-        help="Add kubernetes configs",
+        help="Add Kubernetes configs",
         action="store_true",
         default=None,
         dest="enable_kube",
@@ -109,7 +125,7 @@ def parse_args():
     )
     parser.add_argument(
         "--swagger",
-        help="Enable self-hosted swagger",
+        help="Enable self-hosted Swagger",
         action="store_true",
         default=None,
         dest="self_hosted_swagger",
@@ -123,7 +139,7 @@ def parse_args():
     )
     parser.add_argument(
         "--quite",
-        help="Do not ask for feature during generation",
+        help="Do not ask for features during generation",
         action="store_true",
         default=False,
         dest="quite",
@@ -150,6 +166,10 @@ def ask_features(current_context: BuilderContext) -> BuilderContext:
             "name": "self_hosted_swagger",
             "value": current_context.self_hosted_swagger,
         },
+        "RabbitMQ integration": {
+            "name": "enable_rmq",
+            "value": current_context.enable_rmq,
+        },
     }
     if current_context.db != DatabaseType.none:
         features["Migrations support"] = {
@@ -186,6 +206,14 @@ def read_user_input(current_context: BuilderContext) -> BuilderContext:
     current_context.kube_name = current_context.project_name.replace("_", "-")
     if current_context.project_description is None:
         current_context.project_description = prompt("Project description: ")
+    if current_context.api_type is None:
+        current_context.api_type = radiolist_dialog(
+            "API type",
+            text="Which api type do you want?",
+            values=[(api, api.value) for api in list(APIType)],
+        ).run()
+        if current_context.api_type is None:
+            raise KeyboardInterrupt()
     if current_context.db is None:
         current_context.db = radiolist_dialog(
             "Databases",
