@@ -4,6 +4,11 @@ from typing import Optional
 from pydantic import BaseModel
 
 
+@enum.unique
+class APIType(enum.Enum):
+    rest = "rest"
+    graphql = "graphql"
+
 @enum.unique
 class DatabaseType(enum.Enum):
     none = "none"
@@ -25,6 +30,7 @@ class ORM(enum.Enum):
     sqlalchemy = "sqlalchemy"
     tortoise = "tortoise"
     psycopg = "psycopg"
+    piccolo = "piccolo"
 
 
 class Database(BaseModel):
@@ -46,7 +52,7 @@ DB_INFO = {
     ),
     DatabaseType.postgresql: Database(
         name=DatabaseType.postgresql.value,
-        image="postgres:13.4-buster",
+        image="postgres:13.6-bullseye",
         async_driver="postgresql+asyncpg",
         driver_short="postgres",
         driver="postgresql",
@@ -54,7 +60,7 @@ DB_INFO = {
     ),
     DatabaseType.mysql: Database(
         name=DatabaseType.mysql.value,
-        image="bitnami/mysql:8.0.26",
+        image="bitnami/mysql:8.0.28",
         async_driver="mysql+aiomysql",
         driver_short="mysql",
         driver="mysql",
@@ -76,11 +82,13 @@ SUPPORTED_ORMS = {
         ORM.psycopg,
         ORM.tortoise,
         ORM.sqlalchemy,
+        ORM.piccolo,
     ],
     DatabaseType.sqlite: [
         ORM.ormar,
         ORM.tortoise,
         ORM.sqlalchemy,
+        ORM.piccolo,
     ],
     DatabaseType.mysql: [
         ORM.ormar,
@@ -95,7 +103,7 @@ ORMS_WITHOUT_MIGRATIONS = [
 
 class BuilderContext(BaseModel):
     """Options for project generation."""
-
+    api_type: Optional[APIType]
     project_name: Optional[str]
     kube_name: Optional[str]
     project_description: Optional[str]
@@ -109,6 +117,7 @@ class BuilderContext(BaseModel):
     enable_routers: Optional[bool]
     add_dummy: Optional[bool] = False
     self_hosted_swagger: Optional[bool]
+    enable_rmq: Optional[bool]
     force: bool = False
     quite: bool = False
 
