@@ -1,6 +1,7 @@
 from fastapi.routing import APIRouter
 
 {%- if cookiecutter.enable_routers == "True" %}
+{%- if cookiecutter.api_type == 'rest' %}
 from {{cookiecutter.project_name}}.web.api import echo
 {%- if cookiecutter.add_dummy == 'True' %}
 from {{cookiecutter.project_name}}.web.api import dummy
@@ -8,6 +9,10 @@ from {{cookiecutter.project_name}}.web.api import dummy
 {%- if cookiecutter.enable_redis == "True" %}
 from {{cookiecutter.project_name}}.web.api import redis
 {%- endif %}
+{%- if cookiecutter.enable_rmq == "True" %}
+from {{cookiecutter.project_name}}.web.api import rabbit
+{%- endif %}
+{%- endif %}
 {%- endif %}
 {%- if cookiecutter.self_hosted_swagger == "True" %}
 from {{cookiecutter.project_name}}.web.api import docs
@@ -20,6 +25,7 @@ api_router.include_router(monitoring.router)
 api_router.include_router(docs.router)
 {%- endif %}
 {%- if cookiecutter.enable_routers == "True" %}
+{%- if cookiecutter.api_type == 'rest' %}
 api_router.include_router(echo.router, prefix="/echo", tags=["echo"])
 {%- if cookiecutter.add_dummy == 'True' %}
 api_router.include_router(dummy.router, prefix="/dummy", tags=["dummy"])
@@ -27,4 +33,8 @@ api_router.include_router(dummy.router, prefix="/dummy", tags=["dummy"])
 {%- if cookiecutter.enable_redis == "True" %}
 api_router.include_router(redis.router, prefix="/redis", tags=["redis"])
 {%- endif %}
+{%- if cookiecutter.enable_rmq == "True" %}
+api_router.include_router(rabbit.router, prefix="/rabbit", tags=["rabbit"])
+{%- endif %}
+{%- endif %}
 {%- endif %}
